﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class RenderSettingApplier {

	public void Apply(IRenderSettingPreset preset) {
		foreach (VisualBlueprint b in preset.GetVisualBlueprints()) {
			Apply(b);
		}
	}

	public void Apply(VisualBlueprint blueprint) {

		GameObject[] allObjects = GameObject.FindGameObjectsWithTag(blueprint.GetName());

		foreach (GameObject currObject in allObjects) {
			if (currObject.activeInHierarchy) {
				ReplaceVisualComponents(currObject, blueprint.GetBlueprintObject());
			}

			Debug.Log("Applying blueprint: " + blueprint.GetName() + " to object: " + currObject.name);
		}
	}

	/**
		Replace the visual components of the target with those of the reference
	**/
	private void ReplaceVisualComponents(GameObject target, GameObject reference)
	{
		GameObject replacement = Object.Instantiate(reference, target.transform.position, target.transform.rotation);

		replacement.name = target.name;
		replacement.layer = target.layer;
		replacement.tag = target.tag;

		if (target.transform.parent != null) {
			replacement.transform.SetParent(target.transform.parent);
		}
		Object.DestroyImmediate(target);

	}
}
